/*
 * #%L
 * ImageJ software for multidimensional image processing and analysis.
 * %%
 * Copyright (C) 2009 - 2013 Board of Regents of the University of
 * Wisconsin-Madison, Broad Institute of MIT and Harvard, and Max Planck
 * Institute of Molecular Cell Biology and Genetics.
 * %%
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of any organization.
 * #L%
 */

package imagej.legacy;

import static org.junit.Assert.assertTrue;

import ij.IJ;

import org.junit.Test;

/**
 * Tests that the CodeHacker gives a helpful message when ImageJ 1.x classes
 * were already loaded.
 * 
 * @author Johannes Schindelin
 */
public class CodeHackerIT {

	@Test
	public void testExceptionMessage() {
		IJ.log("Now ij.IJ is loaded.");
		try {
			DefaultLegacyService.preinit();
			assertTrue("Should never reach here", false);
		} catch (ExceptionInInitializerError e) {
			final Throwable e2 = e.getCause();
			assertTrue(e2 != null);
			assertTrue(e2 instanceof RuntimeException);
			final Throwable e3 = e2.getCause();
			assertTrue(e3 != null);
			assertTrue("should be a LinkageError: " + e3, e3 instanceof LinkageError);
			final String cause = e2.getMessage();
			assertTrue("Contains hint:\n\n" + cause, cause.indexOf("-javaagent:") > 0);
			IJ.log("We got the hint, and all is fine:\n\n" + cause);
		}
	}

}

